@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model;
-$Config::Model::VERSION = '2.113';
+$Config::Model::VERSION = '2.114';
 use strict ;
 use warnings;
 use 5.10.1;
@@ -350,7 +350,7 @@ my @legal_params_to_move = (
     # this parameter is filled by class generated by a program. It may
     # be used to avoid interactive edition of a generated model
     'generated_by',
-    qw/class_description author copyright license include include_after include_backend class/
+    qw/class_description author copyright gist license include include_after include_backend class/
 );
 
 my @other_legal_params = qw/ author element status description summary level accept/;
@@ -697,51 +697,56 @@ sub translate_legacy_info {
     ) if $legacy_logger->is_debug;
 }
 
-# TODO: use 'die' mid November 2017
 sub translate_legacy_backend_info {
     my ( $self, $config_class_name, $model ) = @_;
 
-    my $multi_backend = 0;
-    my $has_custom = 0;
+    # trap multi backend and change array spec into single spec
     foreach my $config (qw/read_config write_config/) {
         my $ref = $model->{$config};
         if ($ref and ref($ref) eq 'ARRAY') {
-            map { $has_custom++ if $_->{backend} eq 'custom' } @$ref;
             if (@$ref == 1) {
                 $model->{$config} = $ref->[0];
             }
             elsif (@$ref > 1){
-                $self->show_legacy_issue("$config_class_name $config: multiple backends are deprecated", 'warn');
-                $multi_backend++;
+                $self->show_legacy_issue("$config_class_name $config: multiple backends are obsolete. You now must use only one backend.", 'die');
             }
         }
     }
 
-    my $ref = $model->{'rw_config'};
-    if ($ref and $ref->{backend} eq 'custom') {
-        $has_custom++;
+    # move read_config spec in re_config
+    if ($model->{read_config}) {
+        $self->show_legacy_issue("$config_class_name: read_config specification is deprecated, please move in rw_config", 'warn');
+        $model->{rw_config} = delete $model->{read_config};
     }
 
-    if ($has_custom) {
+    # merge write_config spec in rw_config
+    if ($model->{write_config}) {
+        $self->show_legacy_issue("$config_class_name: write_config specification is deprecated, please merge with read_config and move in rw_config", 'warn');
+        map {$model->{rw_config}{$_} = $model->{write_config}{$_} } keys %{$model->{write_config}} ;
+        delete $model->{write_config};
+    }
+
+    my $ref = $model->{'rw_config'} || return;
+
+    die "undefined backend in rw_config spec of class $config_class_name\n" unless $ref->{backend} ;
+
+    if ($ref->{backend} eq 'custom') {
         my $msg = "$config_class_name: custom read/write backend is obsolete."
             ." Please replace with a backend inheriting Config::Model::Backend::Any";
         $self->show_legacy_issue( $msg, 'die');
     }
 
-    if ($model->{read_config}) {
-        $self->show_legacy_issue("$config_class_name: read_config specification is deprecated, please move in rw_config", 'note');
-        # TODO: enable once COnfig::Model::Itself is ready
-        # $model->{rw_config} = delete $model->{read_config} unless $multi_backend;
+    if ( $ref->{backend} =~ /^(perl|ini|cds)$/ ) {
+        my $backend = $ref->{backend};
+        $self->show_legacy_issue("$config_class_name: deprecated backend '$backend'. Should be '$ {backend}_file'", 'warn');
+        $ref->{backend} .= "_file";
     }
 
-    if ($model->{write_config}) {
-        $self->show_legacy_issue("$config_class_name: write_config specification is deprecated, please merge with read_config and move in rw_config", 'note');
-        # TODO: enable once Config::Model::Itself is ready
-        #if (not $multi_backend) {
-        #    map {$model->{rw_config}{$_} = $model->{write_config}{$_} } keys %{$model->{write_config}} ;
-        #    delete $model->{write_config};
-        #}
+    if ( defined $ref->{allow_empty} ) {
+        $self->show_legacy_issue("$config_class_name: backend $ref->{backend}: allow_empty is deprecated. Use auto_create", 'warn');
+        $ref->{auto_create} = delete $ref->{allow_empty};
     }
+
 }
 
 sub translate_cargo_info {
@@ -1841,7 +1846,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.113
+version 2.114
 
 =head1 SYNOPSIS
 
