@@ -8,12 +8,14 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Role::NodeLoader;
-$Config::Model::Role::NodeLoader::VERSION = '2.113';
+$Config::Model::Role::NodeLoader::VERSION = '2.114';
 # ABSTRACT: Load Node element in configuration tree
 
 use Mouse::Role;
 use strict;
 use warnings;
+use Carp;
+use 5.10.0;
 
 use Mouse::Util;
 use Log::Log4perl qw(get_logger :levels);
@@ -29,6 +31,10 @@ sub load_node {
     $load_logger->info("Loading $config_class_name ". $self->location . " with $node_class");
     Mouse::Util::load_class($node_class);
 
+    if (delete $params{check}) {
+        carp "load_node; drop check param. Better let node query the instance";
+    }
+    $params{gist} //=  $config_class->{gist} if $config_class->{gist};
     return $node_class->new(%params) ;
 }
 
@@ -44,7 +50,7 @@ Config::Model::Role::NodeLoader - Load Node element in configuration tree
 
 =head1 VERSION
 
-version 2.113
+version 2.114
 
 =head1 SYNOPSIS
 
