@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::WarpedNode;
-$Config::Model::WarpedNode::VERSION = '2.113';
+$Config::Model::WarpedNode::VERSION = '2.114';
 use Mouse;
 
 use Carp qw(cluck croak);
@@ -33,7 +33,7 @@ my $logger = get_logger("Tree::Node::Warped");
 # status is not warpable either as an obsolete parameter must stay
 # obsolete
 
-my @allowed_warp_params = qw/config_class_name level/;
+my @allowed_warp_params = qw/config_class_name level gist/;
 
 has 'backup' => ( is => 'rw', isa => 'HashRef', default => sub { {}; } );
 
@@ -80,7 +80,7 @@ sub config_model {
 # Forward selected methods (See man perltootc)
 foreach my $method (
     qw/fetch_element config_class_name copy_from get_element_name
-    has_element is_element_available element_type load
+    gist has_element is_element_available element_type load
     fetch_element_value get_type get_cargo_type dump_tree needs_save
     describe get_help get_help_as_text children get set accept_regexp/
     ) {
@@ -313,7 +313,7 @@ Config::Model::WarpedNode - Node that change config class properties
 
 =head1 VERSION
 
-version 2.113
+version 2.114
 
 =head1 SYNOPSIS
 
